@@ -6,8 +6,11 @@
 //! This crate consists of the following modules:
 //! * [architectures]: Helpers to handle Debian architectures
 //! * [archive]: Helpers for various features of the Debian archive
+//! * [autoremovals]: Helpers to handle autoremovals
 //! * [buildinfo]: Helpers to handle `.buildinfo` files
 //! * [excuses]: Helpers to handle `excuses.yaml` for testing migration
+//! * [package]: Helpers to handle package names
+//! * [release]: Helpers to handle `Release` files
 //! * [version]: Helpers to handle package versions
 //! * [wb]: Helpers to generate commands for wanna-build
 
@@ -22,6 +25,7 @@ pub mod archive;
 pub mod autoremovals;
 pub mod buildinfo;
 pub mod excuses;
+pub mod package;
 pub mod release;
 mod utils;
 pub mod version;
@@ -57,4 +61,7 @@ pub enum ParseError {
     #[error("invalid component")]
     /// Given string is not a valid component
     InvalidComponent,
+    #[error("invalid package: {0}")]
+    /// Given string is not a valid package
+    InvalidPackage(#[from] package::PackageError),
 }
