@@ -5,7 +5,7 @@
 //!
 //! These helpers includes abstractions to check the validity of Debian packages names.
 
-use std::fmt::Display;
+use std::{borrow::Borrow, fmt::Display};
 
 use serde::Deserialize;
 use thiserror::Error;
@@ -66,6 +66,12 @@ impl AsRef<str> for PackageName {
     }
 }
 
+impl Borrow<str> for PackageName {
+    fn borrow(&self) -> &str {
+        self.0.as_str()
+    }
+}
+
 impl PartialEq<&str> for PackageName {
     fn eq(&self, other: &&str) -> bool {
         self.0.eq(other)
