@@ -5,17 +5,22 @@
 //!
 //! This module provides builders to generate commands for [wanna-build](https://release.debian.org/wanna-build.txt).
 
-use std::fmt::{Display, Formatter};
-use std::io::Write;
-use std::process::{Command, Stdio};
-use std::str::FromStr;
+use std::{
+    fmt::{Display, Formatter},
+    io::Write,
+    process::{Command, Stdio},
+    str::FromStr,
+};
 
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
-use crate::architectures::{Architecture, ParseError};
-use crate::archive::{Suite, SuiteOrCodename};
-use crate::version::PackageVersion;
+use crate::{
+    architectures::{Architecture, ParseError},
+    archive::{Suite, SuiteOrCodename},
+    package::PackageName,
+    version::PackageVersion,
+};
 
 /// Errors when working with `wb`
 #[derive(Debug, Error)]
@@ -124,7 +129,7 @@ impl FromStr for WBArchitecture {
 /// Specifier for a source with version, architecture and suite
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct SourceSpecifier<'a> {
-    source: &'a str,
+    source: &'a PackageName,
     version: Option<&'a PackageVersion>,
     architectures: Vec<WBArchitecture>,
     suite: Option<SuiteOrCodename>,
@@ -132,7 +137,7 @@ pub struct SourceSpecifier<'a> {
 
 impl<'a> SourceSpecifier<'a> {
     /// Create a new source specifier for the given source package name.
-    pub fn new(source: &'a str) -> Self {
+    pub fn new(source: &'a PackageName) -> Self {
         Self {
             source,
             version: None,
@@ -404,15 +409,48 @@ impl WBCommandBuilder for Fail<'_> {
     }
 }
 
+/// Builder for the `info` command
+#[derive(Clone, Debug, Eq, PartialEq)]
+pub struct Info<'a> {
+    source: &'a SourceSpecifier<'a>,
+}
+
+impl<'a> Info<'a> {
+    /// Create a new `info` command for the given `source`.
+    pub fn new(source: &'a SourceSpecifier<'a>) -> Result<Self, Error> {
+        for arch in &source.architectures {
+            match *arch {
+                // unable to info with source, -source
+                WBArchitecture::Architecture(Architecture::Source)
+                | WBArchitecture::ExcludeArchitecture(Architecture::Source) => {
+                    return Err(Error::InvalidArchitecture(*arch, "info"));
+                }
+                _ => {}
+            }
+        }
+
+        Ok(Self { source })
+    }
+}
+
+impl Display for Info<'_> {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "info {}", self.source)
+    }
+}
+
+impl WBCommandBuilder for Info<'_> {
+    fn build(&self) -> WBCommand {
+        WBCommand(self.to_string())
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::{
         BinNMU, BuildPriority, DepWait, Fail, SourceSpecifier, WBArchitecture, WBCommandBuilder,
     };
-    use crate::architectures::Architecture;
-    use crate::archive::{Suite, SuiteOrCodename};
-
-    const TESTING: SuiteOrCodename = SuiteOrCodename::Suite(Suite::Testing(None));
+    use crate::{architectures::Architecture, archive::SuiteOrCodename, package::PackageName};
 
     #[test]
     fn arch_from_str() {
@@ -437,15 +475,17 @@ mod test {
 
     #[test]
     fn binnmu() {
+        let source = PackageName::try_from("zathura").unwrap();
+
         assert_eq!(
-            BinNMU::new(&SourceSpecifier::new("zathura"), "Rebuild on buildd")
+            BinNMU::new(&SourceSpecifier::new(&source), "Rebuild on buildd")
                 .unwrap()
                 .build()
                 .to_string(),
             "nmu zathura . ANY . unstable . -m \"Rebuild on buildd\""
         );
         assert_eq!(
-            BinNMU::new(&SourceSpecifier::new("zathura"), "Rebuild on buildd")
+            BinNMU::new(&SourceSpecifier::new(&source), "Rebuild on buildd")
                 .unwrap()
                 .with_nmu_version(3)
                 .build()
@@ -454,7 +494,7 @@ mod test {
         );
         assert_eq!(
             BinNMU::new(
-                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
+                SourceSpecifier::new(&source).with_version(&"2.3.4".try_into().unwrap()),
                 "Rebuild on buildd"
             )
             .unwrap()
@@ -464,7 +504,7 @@ mod test {
         );
         assert_eq!(
             BinNMU::new(
-                SourceSpecifier::new("zathura").with_architectures(&[
+                SourceSpecifier::new(&source).with_architectures(&[
                     WBArchitecture::Any,
                     WBArchitecture::ExcludeArchitecture(Architecture::I386)
                 ]),
@@ -477,7 +517,7 @@ mod test {
         );
         assert_eq!(
             BinNMU::new(
-                SourceSpecifier::new("zathura").with_suite(TESTING),
+                SourceSpecifier::new(&source).with_suite(SuiteOrCodename::TESTING),
                 "Rebuild on buildd"
             )
             .unwrap()
@@ -486,21 +526,24 @@ mod test {
             "nmu zathura . ANY . testing . -m \"Rebuild on buildd\""
         );
         assert_eq!(
-            BinNMU::new(&SourceSpecifier::new("zathura"), "Rebuild on buildd").unwrap()
+            BinNMU::new(&SourceSpecifier::new(&source), "Rebuild on buildd")
+                .unwrap()
                 .with_extra_depends("libgirara-dev")
                 .build()
                 .to_string(),
             "nmu zathura . ANY . unstable . -m \"Rebuild on buildd\" --extra-depends \"libgirara-dev\""
         );
         assert_eq!(
-            BinNMU::new(&SourceSpecifier::new("zathura"), "Rebuild on buildd").unwrap()
+            BinNMU::new(&SourceSpecifier::new(&source), "Rebuild on buildd")
+                .unwrap()
                 .with_dependency_wait("libgirara-dev")
                 .build()
                 .to_string(),
             "nmu zathura . ANY . unstable . -m \"Rebuild on buildd\"\ndw zathura . ANY . unstable . -m \"libgirara-dev\""
         );
         assert_eq!(
-            BinNMU::new(&SourceSpecifier::new("zathura"), "Rebuild on buildd").unwrap()
+            BinNMU::new(&SourceSpecifier::new(&source), "Rebuild on buildd")
+                .unwrap()
                 .with_build_priority(-10)
                 .build()
                 .to_string(),
@@ -510,7 +553,8 @@ mod test {
 
     #[test]
     fn nmu_builder() {
-        let source = SourceSpecifier::new("zathura");
+        let source = PackageName::try_from("zathura").unwrap();
+        let source = SourceSpecifier::new(&source);
         let mut builder = BinNMU::new(&source, "Rebuild on buildd").unwrap();
         builder.with_nmu_version(3);
         assert_eq!(
@@ -527,8 +571,10 @@ mod test {
 
     #[test]
     fn bp() {
+        let source = PackageName::try_from("zathura").unwrap();
+
         assert_eq!(
-            BuildPriority::new(&SourceSpecifier::new("zathura"), 10)
+            BuildPriority::new(&SourceSpecifier::new(&source), 10)
                 .unwrap()
                 .build()
                 .to_string(),
@@ -536,7 +582,7 @@ mod test {
         );
         assert_eq!(
             BuildPriority::new(
-                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
+                SourceSpecifier::new(&source).with_version(&"2.3.4".try_into().unwrap()),
                 10
             )
             .unwrap()
@@ -546,7 +592,7 @@ mod test {
         );
         assert_eq!(
             BuildPriority::new(
-                SourceSpecifier::new("zathura").with_architectures(&[
+                SourceSpecifier::new(&source).with_architectures(&[
                     WBArchitecture::Any,
                     WBArchitecture::ExcludeArchitecture(Architecture::I386)
                 ]),
@@ -558,18 +604,23 @@ mod test {
             "bp 10 zathura . ANY -i386 . unstable"
         );
         assert_eq!(
-            BuildPriority::new(SourceSpecifier::new("zathura").with_suite(TESTING), 10)
-                .unwrap()
-                .build()
-                .to_string(),
+            BuildPriority::new(
+                SourceSpecifier::new(&source).with_suite(SuiteOrCodename::TESTING),
+                10
+            )
+            .unwrap()
+            .build()
+            .to_string(),
             "bp 10 zathura . ANY . testing"
         );
     }
 
     #[test]
     fn dw() {
+        let source = PackageName::try_from("zathura").unwrap();
+
         assert_eq!(
-            DepWait::new(&SourceSpecifier::new("zathura"), "libgirara-dev")
+            DepWait::new(&SourceSpecifier::new(&source), "libgirara-dev")
                 .unwrap()
                 .build()
                 .to_string(),
@@ -577,7 +628,7 @@ mod test {
         );
         assert_eq!(
             DepWait::new(
-                SourceSpecifier::new("zathura").with_version(&"2.3.4".try_into().unwrap()),
+                SourceSpecifier::new(&source).with_version(&"2.3.4".try_into().unwrap()),
                 "libgirara-dev"
             )
             .unwrap()
@@ -587,7 +638,7 @@ mod test {
         );
         assert_eq!(
             DepWait::new(
-                SourceSpecifier::new("zathura").with_architectures(&[
+                SourceSpecifier::new(&source).with_architectures(&[
                     WBArchitecture::Any,
                     WBArchitecture::ExcludeArchitecture(Architecture::I386)
                 ]),
@@ -600,7 +651,7 @@ mod test {
         );
         assert_eq!(
             DepWait::new(
-                SourceSpecifier::new("zathura").with_suite(TESTING),
+                SourceSpecifier::new(&source).with_suite(SuiteOrCodename::TESTING),
                 "libgirara-dev"
             )
             .unwrap()
@@ -612,8 +663,10 @@ mod test {
 
     #[test]
     fn fail() {
+        let source = PackageName::try_from("zathura").unwrap();
+
         assert_eq!(
-            Fail::new(&SourceSpecifier::new("zathura"), "#1234")
+            Fail::new(&SourceSpecifier::new(&source), "#1234")
                 .unwrap()
                 .build()
                 .to_string(),
