@@ -15,6 +15,11 @@ fn parse_release_debian_unstable() {
     parse_release("Release-debian-unstable");
 }
 
+#[test]
+fn parse_release_debian_forky() {
+    parse_release("Release-debian-forky");
+}
+
 #[test]
 fn parse_release_debian_trixie() {
     parse_release("Release-debian-trixie");
@@ -25,11 +30,6 @@ fn parse_release_debian_bookworm() {
     parse_release("Release-debian-bookworm");
 }
 
-#[test]
-fn parse_release_debian_bullseye() {
-    parse_release("Release-debian-bullseye");
-}
-
 fn parse_release(data_file: &str) {
     let manifest_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR"));
     let release_path = manifest_dir.join("tests").join("data").join(data_file);
